function VideoAnalysis()
    %**********************************************************************
    %Title: ColorAnalysis.m
    %Purpose: Analyze the stability of spray jets videos
    %Created: 15/April/2016 by Dr. Francisco J. Sanchez Careaga
    %**********************************************************************
    %
    %Global Variables
    %
    %Get Intensity Matrix from the Complete Histogram Data in Matlab Workspace
    %
    clc;
    MatrixRedComp=evalin('base','SimOutRedZoom.signals.values');
    MatrixRedComp=squeeze(MatrixRedComp);
    MatrixGreenComp=evalin('base','SimOutGreenZoom.signals.values');
    MatrixGreenComp=squeeze(MatrixGreenComp);
    MatrixBlueComp=evalin('base','SimOutBlueZoom.signals.values');
    MatrixBlueComp=squeeze(MatrixBlueComp);
    MatrixTimeComp=evalin('base','SimOutRedZoom.time');
    MatrixTimeComp=squeeze(MatrixTimeComp);
    Xsize=size(MatrixRedComp,1);
    Ysize=size(MatrixRedComp,2);
    Tsize=size(MatrixRedComp,3);
    %Note, the axis are backwards.
    fprintf('\nSize of the Matrix and Frames \n\n');
    fprintf('The Size of Matrix Y is: %d\n', Xsize);
    fprintf('The Size of Matrix X is: %d\n', Ysize);
    fprintf('Number of Frames is: %d\n', Tsize);
    RedMatrix=zeros(Xsize, Ysize, Tsize);
    GreenMatrix=zeros(Xsize, Ysize, Tsize);
    BlueMatrix=zeros(Xsize, Ysize, Tsize);
    for i=1:Tsize
        AreaMaxX=0;
        AreaMaxX2=0;
        XCentre=0;
        XMaxCentre2=0;
        for j=1:Ysize
            Xmin=0;
            Xmax=0;
            F1=0;
            for k=1:Xsize
                if (MatrixRedComp(k, j, i)>0.8 && MatrixGreenComp(k, j, i)>0.50 && MatrixGreenComp(k, j, i)<0.70 && MatrixBlueComp(k, j, i)>0.60 && MatrixBlueComp(k, j, i)<0.90)%0.992
                    RedMatrix(k,j,i)=MatrixRedComp(k, j, i);
                    GreenMatrix(k,j,i)=MatrixGreenComp(k, j, i);
                    BlueMatrix(k,j,i)=MatrixBlueComp(k, j, i);
                    if (F1==0)
                        Xmin=k;
                        F1=1;
                    end
                    if (F1==1)
                        Xmax=k;
                        XCentre=round(Xmin+(Xmax-Xmin)/2);
                        AreaX=(Xmax-Xmin)*1;
                    end
                else
                    if (F1==1)
                        if(AreaX>AreaMaxX)
                            AreaMaxX=AreaX;
                            XMaxCentre=XCentre;
                        end
                    end
                    Xmin=0;
                    Xmax=0;
                    AreaX=0;
                    F1=0;
                end
            end
            if(AreaMaxX>AreaMaxX2)
                AreaMaxX2=AreaMaxX;
                XMaxCentre2=XMaxCentre;
            end
        end
        XC(i)=XMaxCentre2;
    end 
    for i=1:Tsize
        AreaMaxY=0;
        AreaMaxY2=0;
        YCentre=0;
        YMaxCentre2=0;
        for j=1:Xsize
            Ymin=0;
            Ymax=0;
            F1=0;
            for k=1:Ysize
                if (MatrixRedComp(j, k, i)>0.8 && MatrixGreenComp(j, k, i)>0.50 && MatrixGreenComp(j, k, i)<0.70 && MatrixBlueComp(j, k, i)>0.60 && MatrixBlueComp(j, k, i)<0.90)%0.992
                    if (F1==0)
                        Ymin=k;
                        F1=1;
                    end
                    if (F1==1)
                        Ymax=k;
                        YCentre=round(Ymin+(Ymax-Ymin)/2);
                        AreaY=(Ymax-Ymin)*1;
                    end
                else
                    if (F1==1)
                        if(AreaY>AreaMaxY)
                            AreaMaxY=AreaY;
                            YMaxCentre=YCentre;
                        end
                    end
                    Ymin=0;
                    Ymax=0;
                    AreaY=0;
                    F1=0;
                end
            end
            if(AreaMaxY>AreaMaxY2)
                AreaMaxY2=AreaMaxY;
                YMaxCentre2=YMaxCentre;
            end
        end
        YC(i)=YMaxCentre2;
    end 
    for i=1:Tsize
        for j=1:Ysize
            for k=1:Xsize
                if (k>XC(i)-1 && k<XC(i)+1)
                     GreenMatrix(k,j,i)=1.0;
                end 
                if (j>YC(i)-1 && j<YC(i)+1)
                     GreenMatrix(k,j,i)=1.0;
                end 
            end
        end
    end 
%
%
%
%     % Subroutine to Create an Image from an RGB Matrix
%     RedMatrix=squeeze(RedMatrix);
%     GreenMatrix=squeeze(GreenMatrix);
%     BlueMatrix=squeeze(BlueMatrix);
%     RGB = cat(3,RedMatrix(:,:,1),GreenMatrix(:,:,1),BlueMatrix(:,:,1));
%     %imshow(RGB); 
%     % Subroutine to Create a video from an RGB Matrix
%     RVID = double(zeros(Xsize,Ysize,1,Tsize)); 
%     for i=1:Tsize
%         RGB = cat(3,RedMatrix(:,:,i),GreenMatrix(:,:,i),BlueMatrix(:,:,i));
%         imshow(RGB);
%         pause(0.01);
%     end
%     % Subroutine to Create a Video from an RBG Matrix for each frame
%     for i=1:Tsize
%         RGB = (cat(3,RedMatrix(:,:,i),GreenMatrix(:,:,i),BlueMatrix(:,:,i)));
%         M(i)=im2frame(RGB);
%     end
%     implay(M);
%     Subroutine to Create a Video from the original RBG Matrix for each frame in
    RedMatrixVideo=MatrixRedComp;
    GreenMatrixVideo=MatrixGreenComp;
    BlueMatrixVideo=MatrixBlueComp;   
    for i=1:Tsize
        for j=1:Ysize
            for k=1:Xsize
                if (k>XC(i)-1 && k<XC(i)+1)
                     GreenMatrixVideo(k,j,i)=1.0;
                end 
                if (j>YC(i)-1 && j<YC(i)+1)
                     GreenMatrixVideo(k,j,i)=1.0;
                end 
            end
        end
    end 
    for i=1:Tsize
        RGB = (cat(3,RedMatrixVideo(:,:,i),GreenMatrixVideo(:,:,i),BlueMatrixVideo(:,:,i)));
        M(i)=im2frame(RGB);
    end
    %Save the Movie
    fprintf(1,'\n');
    fprintf(1,'Video with the Red Dot Center:\n');
    if (nargin < 2)
        fprintf (1,'\n');
        Question01 = input(...
        'Do you want to save the movie (Yes = 1 - No = 0): ');
    end
    if (Question01==1)
        VideoWriter('Movement.avi');
    end
    % Show the movie
    fprintf(1,'\n');
    fprintf(1,'Video with the Red Dot Center:\n');
    if (nargin < 2)
        fprintf (1,'\n');
        Question02 = input(...
        'Do you want to play the movie (Yes = 1 - No = 0): ');
    end
    if (Question02==1)
        implay(M);
    end
    %Plot graphe
    %Note, the axis above this line are backwards, I am fixing them below.
    %Figure #1 - Y position
    figure('Name', 'Movement in the Y coordinate vs time');
    hold on
    plot (MatrixTimeComp,XC);
    set(gca,'FontSize',17, 'XTick', (0:round(max(MatrixTimeComp)/10):max(MatrixTimeComp)), 'YTick', (0:round(max(XC)/20):max(XC)));
    set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%3.0f'));
    set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%3.0f'));
    xlabel(['Time (s)'], 'fontsize', 17, 'fontweight', 'b');
    ylabel(['Position Y Coordinate'], 'fontsize', 17, 'fontweight', 'b');
    title({['Movement in the Y coordinate vs time']}, 'fontsize', 17, 'fontweight', 'b');
    hold off
    fig = figure(1);
    set(fig, 'Units', 'normalized', 'OuterPosition', [0,0,1,1], 'color', 'white');
    set(fig,'Renderer','zbuffer');
    print(fig, '-dtiff', '-r500', 'YvsT');
    %Figure #2 - X position
    figure('Name', 'Movement in the X coordinate vs time');
    hold on
    plot (MatrixTimeComp,YC);
    set(gca,'FontSize',17, 'XTick', (0:round(max(MatrixTimeComp)/10):max(MatrixTimeComp)), 'YTick', (0:round(max(YC)/20):max(YC)));
    set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%3.0f'));
    set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%3.0f'));
    xlabel(['Time (s)'], 'fontsize', 17, 'fontweight', 'b');
    ylabel(['Position X Coordinate'], 'fontsize', 17, 'fontweight', 'b');
    title({['Movement in the X coordinate vs time']}, 'fontsize', 17, 'fontweight', 'b');
    hold off
    fig = figure(2);
    set(fig, 'Units', 'normalized', 'OuterPosition', [0,0,1,1], 'color', 'white');
    set(fig,'Renderer','zbuffer');
    print(fig, '-dtiff', '-r500', 'XvsT');
    %Save on File
    FileName01 = 'Results 01 - XYTime.xlsx';
    FileHeader = cell(1,3);
    FileHeader{1}='Time';
    FileHeader{2}='X';
    FileHeader{3}='Y';
    FileValue = zeros(Tsize,3);
    FileValue(:,1)=MatrixTimeComp;
    FileValue(:,2)=YC;
    FileValue(:,3)=XC;
    xlswrite(FileName01,FileHeader, 'Data', 'A1');
    xlswrite(FileName01,FileValue, 'Data', 'A2');

end